#ifndef __ERLANG_H
#define __ERLANG_H

#include <arpa/inet.h>
#include "context.h"
#include "sequences.h"
#include "plugins.h"

/* commands */
#define CMD_CHAR             'C'
#define STOP_CHAR            'S'
#define UPDATE_CHAR          'U'
#define UPDATE_COLORMAP_CHAR 'C'
#define UPDATE_PICTURE_CHAR  'P'
#define UPDATE_SEQUENCE_CHAR 'S'
#define INFO_CHAR            'I'
#define WEBCAM_CHAR          'W'
#define BINIOU_CHAR          'B'

void info(const char *, ...);

ssize_t write_exact(const u_char *, const ssize_t);

#endif /* __ERLANG_H */
